aboutsummaryrefslogtreecommitdiff
path: root/gdb/tracepoint.h
diff options
context:
space:
mode:
authorStan Shebs <shebs@codesourcery.com>2010-03-26 01:46:29 +0000
committerStan Shebs <shebs@codesourcery.com>2010-03-26 01:46:29 +0000
commit6c28cbf2b6beb56c99ec084b9bc5adc8d4813894 (patch)
tree1a4837c78b049a3c055de85cba991b2030200ee1 /gdb/tracepoint.h
parenta45fc99392bdce4c67b43b1a0a05c77e7112afab (diff)
downloadgdb-6c28cbf2b6beb56c99ec084b9bc5adc8d4813894.zip
gdb-6c28cbf2b6beb56c99ec084b9bc5adc8d4813894.tar.gz
gdb-6c28cbf2b6beb56c99ec084b9bc5adc8d4813894.tar.bz2
2010-03-25 Stan Shebs <stan@codesourcery.com>
* tracepoint.h (trace_stop_reason): Add tracepoint_error. (struct trace_status): New field error_desc. * tracepoint.c (stop_reason_names): Add terror. (current_trace_status): Ensure non-NULL error description. (trace_status_command): Add error report. (trace_status_mi): Ditto. (trace_save): Add special case for error description. (parse_trace_status): Add case for errors. * gdb.texinfo (Tracepoint Packets): Document trace error status. * gdb.trace/tfile.c: Generate an additional trace file, improve portability. * gdb.trace/tfile.exp: Test trace file with an error stop, delete files in a better way.
Diffstat (limited to 'gdb/tracepoint.h')
-rw-r--r--gdb/tracepoint.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/gdb/tracepoint.h b/gdb/tracepoint.h
index 723baa2..1da7d26 100644
--- a/gdb/tracepoint.h
+++ b/gdb/tracepoint.h
@@ -73,7 +73,8 @@ enum trace_stop_reason
tstop_command,
trace_buffer_full,
trace_disconnected,
- tracepoint_passcount
+ tracepoint_passcount,
+ tracepoint_error
};
struct trace_status
@@ -89,10 +90,15 @@ struct trace_status
enum trace_stop_reason stop_reason;
- /* If stop_reason == tracepoint_passcount, the on-target number
- of the tracepoint which caused the stop. */
+ /* If stop_reason is tracepoint_passcount or tracepoint_error, this
+ is the (on-target) number of the tracepoint which caused the
+ stop. */
int stopping_tracepoint;
+ /* If stop_reason is tracepoint_error, this is a human-readable
+ string that describes the error that happened on the target. */
+ char *error_desc;
+
/* Number of traceframes currently in the buffer. */
int traceframe_count;